@@ -2151,6 +2151,10 @@ residuals_phregr <- function(
 #'   variance estimate.
 #' @param firth Whether the firth's bias reducing penalized likelihood
 #'   should be used. The default is \code{FALSE}.
+#' @param bc Whether to apply firth's bias correction for noncanonical
+#'   parameterization and weighted logistic regression. The default is
+#'   \code{FALSE}, in which case, the penalized likelihood with Jeffreys
+#'   prior will be used.
 #' @param flic Whether to apply intercept correction to obtain more
 #'   accurate predicted probabilities. The default is \code{FALSE}.
 #' @param plci Whether to obtain profile likelihood confidence interval.
@@ -2203,6 +2207,9 @@ residuals_phregr <- function(
 #'
 #'     - \code{firth}: Whether the firth's penalized likelihood is used.
 #'
+#'     - \code{bc}: Whether to apply firth's bias correction for noncanonical
+#'       parameterization and weighted logistic regression.
+#'
 #'     - \code{flic}: Whether to apply intercept correction.
 #'
 #'     - \code{loglik0_unpenalized}: The unpenalized log-likelihood under null.
@@ -2291,6 +2298,9 @@ residuals_phregr <- function(
 #' * \code{robust}: Whether a robust sandwich variance estimate should be
 #'   computed.
 #'
+#' * \code{bc}: Whether to apply firth's bias correction for noncanonical
+#'   parameterization and weighted logistic regression.
+#'
 #' * \code{firth}: Whether to use the firth's bias reducing penalized
 #'   likelihood.
 #'
@@ -2326,7 +2336,7 @@ residuals_phregr <- function(
 logisregr <- function(data, rep = "", event = "event", covariates = "",
                       freq = "", weight = "", offset = "", id = "",
                       link = "logit", robust = FALSE, firth = FALSE,
-                      flic = FALSE, plci = FALSE, alpha = 0.05) {
+                      bc = FALSE, flic = FALSE, plci = FALSE, alpha = 0.05) {
 
   rownames(data) = NULL
 
@@ -2371,7 +2381,8 @@ logisregr <- function(data, rep = "", event = "event", covariates = "",
   fit <- logisregcpp(data = df, rep = rep, event = event,
                      covariates = varnames, freq = freq, weight = weight,
                      offset = offset, id = id, link = link, robust = robust,
-                     firth = firth, flic = flic, plci = plci, alpha = alpha)
+                     firth = firth, bc = bc, flic = flic, plci = plci,
+                     alpha = alpha)
 
   fit$p <- fit$sumstat$p[1]
   fit$link <- fit$sumstat$link[1]
@@ -2416,6 +2427,7 @@ logisregr <- function(data, rep = "", event = "event", covariates = "",
   fit$id = id
   fit$robust = robust
   fit$firth = firth
+  fit$bc = bc
   fit$flic = flic
   fit$plci = plci
   fit$alpha = alpha
